@@ -4,7 +4,7 @@ use strict;
 BEGIN { eval { require warnings; warnings->import } }
 
 our @EXPORT_OK = qw( rename );
-our $VERSION = '1.19_04';
+our $VERSION = '1.29_01';
 
 sub import {
     require Exporter;
@@ -18,18 +18,27 @@ sub rename_files {
     my $code = shift;
     my $options = shift;
     _default(\$options); 
-
+ 
+    my $sub = $code;
+    if ( $options->{unicode_strings} ) {
+        $sub = sub {    
+            use utf8;
+             use feature 'unicode_strings';
+            utf8::upgrade $_;               
+            $code->(); 
+        };
+    }
     my $errors;
     for (@_) {
         my $was = $_;
 	if ( $options->{filename_only} ) {
 	    require File::Spec;
 	    my($vol, $dir, $file) = File::Spec->splitpath($_);
-	    $code->() for ($file);
+	    $sub->() for ($file);
 	    $_ = File::Spec->catpath($vol, $dir, $file);
 	}
 	else {
-	    $code->();
+	    $sub->();
 	}
 
     	if( $was eq $_ ){ }		# ignore quietly
