@@ -6,7 +6,7 @@ BEGIN { eval { require warnings; warnings->import } }
 use Getopt::Long ();
 
 use vars qw($VERSION);
-$VERSION = '1.09_03';	
+$VERSION = '1.10';	
 
 eval{ Getopt::Long::Configure qw(
 	posix_default
@@ -35,6 +35,7 @@ sub GetOptions {
 		$e .= ';'; 
 		push @expression, $e; 
 	    },
+     '-u|uncode'    => \my $unicode,
     ) or return;
 
     my $options = {
@@ -46,6 +47,7 @@ sub GetOptions {
 	show_help	=> $help,
 	show_manual	=> $man,
 	show_version	=> $version,
+    unicode_strings => $unicode,
     };
     return $options if $no_code;
     return $options if $help or $man or $version;
