@@ -36,10 +36,9 @@ sub create_file {
     local *FILE; 
     if (open  FILE, '>', $file) {
     	print FILE @_;
-    	close FILE or die $!;
-	return 1;
+        return 1 if close FILE;
     }
-    $file =~ s/\n/\\n/;
+    $file =~ s/\s/\\s/g;
     diag "Can't create file \"$file\": $!\n";
     return;
 } 
